@@ -4,11 +4,10 @@
 
 import jsonpClient from '../client/jsonp';
 
-export default function (request, next) {
+export default function (request) {
 
     if (request.method == 'JSONP') {
         request.client = jsonpClient;
     }
 
-    next();
 }
