@@ -2,12 +2,11 @@
  * HTTP method override Interceptor.
  */
 
-export default function (request, next) {
+export default function (request) {
 
     if (request.emulateHTTP && /^(PUT|PATCH|DELETE)$/i.test(request.method)) {
         request.headers.set('X-HTTP-Method-Override', request.method);
         request.method = 'POST';
     }
 
-    next();
 }
